@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '1.7.9';
+    return '1.7.9.1';
   }
 
   function GetHelp()
